/*-------------------------------------------------------------------------
 *
 * recoverycmds.h
 *	  prototypes for recoverycmds.c
 *
 *
 * Copyright (c) 2002, PostgreSQL Global Development Group
 *
 * $Id: recoverycmds.h,v 1.1 2002/08/21 12:58:09 jnield Exp jnield $
 *
 *-------------------------------------------------------------------------
 */

#ifndef RECOVERYCMDS_H
#define RECOVERYCMDS_H

#include "nodes/parsenodes.h"
#include "access/xlogdefs.h"
#include "catalog/pg_control.h"

typedef enum InteractiveRecoveryCmdType {
	IRCT_EOF,
	IRCT_EMPTY,
	IRCT_INIT_INTERACTIVE,
	IRCT_INFO_CONTROL,
	IRCT_INFO_LOGFILES,
	IRCT_VRFY_LOGFILES,
	IRCT_RECOVER,
	IRCT_FINISH,
	IRCT_ABORT
} InteractiveRecoveryCmdType;

struct IRC_LogFileInfoCmd {
	XLogRecPtr		start;
	XLogRecPtr		end;
	bool			detailed;
};

struct IRC_LogFileVerifyCmd {
	XLogRecPtr		start;
	XLogRecPtr		end;
};

#define IRC_RC_TO_POINT			(1)
#define IRC_RC_FROM_SOURCE		(1<<1)

struct IRC_RecoverCmd {
	int				rc_flags;
	XLogRecPtr		finish_point;
	char			*source_dir;
};

struct IRC_FinishCmd {
	DBState			new_ctl_state;
};

typedef struct InteractiveRecoveryCmdData {
	InteractiveRecoveryCmdType		irc_type;
	union {
		struct IRC_LogFileInfoCmd		fic;
		struct IRC_LogFileVerifyCmd		ver;
		struct IRC_RecoverCmd			reco;
		struct IRC_FinishCmd			fini;
	} irc;
} InteractiveRecoveryCmdData, *InteractiveRecoveryCmd;

extern void AlterSystemBackup(AlterSystemBackupStmt *stmt);
extern void InteractiveRecoveryPrompt( InteractiveRecoveryCmd cmd_out );

#endif  /* RECOVERYCMDS_H */
